if (!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")
BiocManager::install("limma")

install.packages("ggplot2")
install.packages("ggpubr")
install.packages("ggExtra")



library(limma)
library(ggplot2)
library(ggpubr)
library(ggExtra)

inputFile="test.normalize.txt"         
geneFile="importanceGene.SVM.txt"    
cliFile="clinic.txt"               
setwd("C:\\Users\\lenovo\\Desktop\\new article\\24")    
data=read.table(inputFile, header=T, sep="\t", check.names=F, row.names=1)
row.names(data)=gsub("-", "_", row.names(data))

geneRT=read.table(geneFile, header=T, sep="\t", check.names=F)
data=data[as.vector(geneRT[,1]),]


group=sapply(strsplit(colnames(data),"\\_"), "[", 2)
data=data[,group=="Treat"]
colnames(data)=gsub("_Treat", "", colnames(data))


clinical=read.table(cliFile, header=T, sep="\t", check.names=F, row.names=1)
cliName=colnames(clinical)[1]
sameSample=intersect(colnames(data), row.names(clinical))
clinical=clinical[sameSample,,drop=F]
data=data[,sameSample,drop=F]

y=as.numeric(clinical[,cliName])
outTab=data.frame()
for(i in row.names(data)){
	x=as.numeric(data[i,])
	corT=cor.test(x, y, method = 'spearman')
	cor=corT$estimate
	pvalue=corT$p.value
	outTab=rbind(outTab, cbind(Gene=i, Clinical=cliName, cor, pvalue))
	#??????????ͼ??
	df1=as.data.frame(cbind(x,y))
	p1=ggplot(df1, aes(x, y)) + 
			xlab(i)+ylab(cliName)+ 
			geom_point()+ geom_smooth(method="lm",formula = y ~ x) + theme_bw()+
			stat_cor(method = 'spearman', aes(x =x, y =y))
	p2=ggMarginal(p1, type = "histogram", xparams = list(fill = "orange"),yparams = list(fill = "blue"))
	
	pdf(file=paste0(cliName,"_",i,".pdf"), width=5, height=4.5)
	print(p2)
	dev.off()
}

write.table(file="corResult.txt",outTab,sep="\t",quote=F,row.names=F)


library(limma)
library(pheatmap)

expFile="crgGeneExp.txt"      
setwd("C:\\Users\\lenovo\\Desktop\\5")     

rt=read.table(expFile, header=T, sep="\t", check.names=F)
rt=as.matrix(rt)
rownames(rt)=rt[,1]
exp=rt[,2:ncol(rt)]
dimnames=list(rownames(exp),colnames(exp))
data=matrix(as.numeric(as.matrix(exp)),nrow=nrow(exp),dimnames=dimnames)
data=avereps(data)
data=data[rowMeans(data)>0,]
Type=gsub("(.*)\\_(.*)", "\\2", colnames(data))
conNum=length(Type[Type=="Control"])
treatNum=length(Type[Type=="Treat"])

sigVec=c()
sigGeneVec=c()
diffTab=data.frame()
for(i in row.names(data)){
  test=wilcox.test(data[i,] ~ Type)
  pvalue=test$p.value
  Sig=ifelse(pvalue<0.001,"***",ifelse(pvalue<0.01,"**",ifelse(pvalue<0.05,"*","")))
  conMean=mean(data[i,1:conNum])
  treatMean=mean(data[i,(conNum+1):ncol(data)])
  logFC=treatMean-conMean
  if(pvalue<0.05){
    sigVec=c(sigVec, paste0(i, Sig))
    sigGeneVec=c(sigGeneVec, i)
    if(logFC>0){diffTab=rbind(diffTab, cbind(Gene=i,conMean,treatMean,pvalue,Type="Up"))}
    if(logFC<0){diffTab=rbind(diffTab, cbind(Gene=i,conMean,treatMean,pvalue,Type="Down"))}
  }
}

write.table(diffTab, file="diff.txt", sep="\t", quote=F, row.names=F)
data=data[sigGeneVec,]
outTab=rbind(ID=colnames(data), data)
write.table(outTab, file="diffGeneExp.txt", sep="\t", quote=F, col.names=F)
row.names(data)=sigVec
